]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
sr: Fix/document probe names.
[libsigrok.git] / sigrok.h
index e8e770f6d87b089238c7bbc71d01bf70e10abd05..10a483f377fb6ee47d3b245856c831f725f515c3 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -94,7 +94,7 @@ extern "C" {
 
 typedef int (*sr_receive_data_callback) (int fd, int revents, void *user_data);
 
/* Data types used by hardware plugins for set_configuration() */
 enum {
        SR_T_UINT64,
        SR_T_CHAR,
@@ -131,7 +131,7 @@ struct sr_datafeed_logic {
 struct sr_input {
        struct sr_input_format *format;
        char *param;
-       struct sr_device *vdevice;
+       struct sr_dev *vdev;
 };
 
 struct sr_input_format {
@@ -144,7 +144,7 @@ struct sr_input_format {
 
 struct sr_output {
        struct sr_output_format *format;
-       struct sr_device *device;
+       struct sr_dev *dev;
        char *param;
        void *internal;
 };
@@ -171,11 +171,11 @@ struct sr_datastore {
  * This represents a generic device connected to the system.
  * For device-specific information, ask the plugin. The plugin_index refers
  * to the device index within that plugin; it may be handling more than one
* device. All relevant plugin calls take a device_index parameter for this.
  */
-struct sr_device {
+struct sr_dev {
        /* Which plugin handles this device */
-       struct sr_device_plugin *plugin;
+       struct sr_dev_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
        /* List of struct sr_probe* */
@@ -210,7 +210,7 @@ enum {
        /*--- Device types --------------------------------------------------*/
 
        /** The device is demo device. */
-       SR_HWCAP_DEMO_DEVICE,
+       SR_HWCAP_DEMO_DEV,
 
        /*--- Device options ------------------------------------------------*/
 
@@ -270,7 +270,7 @@ enum {
 };
 
 struct sr_hwcap_option {
-       int capability;
+       int hwcap;
        int type;
        char *description;
        char *shortname;
@@ -279,7 +279,7 @@ struct sr_hwcap_option {
 struct sr_dev_inst {
        int index;
        int status;
-       int instance_type;
+       int inst_type;
        char *vendor;
        char *model;
        char *version;
@@ -288,8 +288,8 @@ struct sr_dev_inst {
 
 /* sr_dev_inst types */
 enum {
-       SR_USB_INSTANCE,
-       SR_SERIAL_INSTANCE,
+       SR_USB_INST,
+       SR_SERIAL_INST,
 };
 
 /* Device instance status */
@@ -311,7 +311,7 @@ enum {
 /* Device info IDs */
 enum {
        /* struct sr_dev_inst for this specific device */
-       SR_DI_INSTANCE,
+       SR_DI_INST,
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
        /* The probe names on this device */
@@ -338,28 +338,28 @@ struct sr_samplerates {
        uint64_t *list;
 };
 
-struct sr_device_plugin {
+struct sr_dev_plugin {
        /* Plugin-specific */
        char *name;
        char *longname;
        int api_version;
-       int (*init) (const char *deviceinfo);
+       int (*init) (const char *devinfo);
        int (*cleanup) (void);
 
        /* Device-specific */
-       int (*opendev) (int device_index);
-       int (*closedev) (int device_index);
-       void *(*get_device_info) (int device_index, int device_info_id);
-       int (*get_status) (int device_index);
-       int *(*get_capabilities) (void);
-       int (*set_configuration) (int device_index, int capability, void *value);
-       int (*start_acquisition) (int device_index, gpointer session_device_id);
-       int (*stop_acquisition) (int device_index, gpointer session_device_id);
+       int (*dev_open) (int dev_index);
+       int (*dev_close) (int dev_index);
+       void *(*dev_info_get) (int dev_index, int dev_info_id);
+       int (*dev_status_get) (int dev_index);
+       int *(*hwcap_get_all) (void);
+       int (*dev_config_set) (int dev_index, int hwcap, void *value);
+       int (*dev_acquisition_start) (int dev_index, gpointer session_dev_id);
+       int (*dev_acquisition_stop) (int dev_index, gpointer session_dev_id);
 };
 
 struct sr_session {
-       /* List of struct sr_device* */
-       GSList *devices;
+       /* List of struct sr_dev* */
+       GSList *devs;
        /* list of sr_receive_data_callback */
        GSList *datafeed_callbacks;
        GTimeVal starttime;
@@ -94,7 +94,7 @@ extern "C" {
 typedef int (*sr_receive_data_callback) (int fd, int revents, void *user_data);
 
-/* Data types used by hardware plugins for set_configuration() */
+/* Data types used by hardware plugins for dev_config_set() */
 enum {
        SR_T_UINT64,
@@ -171,11 +171,11 @@ struct sr_datastore {
  * For device-specific information, ask the plugin. The plugin_index refers
  * to the device index within that plugin; it may be handling more than one
- * device. All relevant plugin calls take a device_index parameter for this.
+ * device. All relevant plugin calls take a dev_index parameter for this.
  */